@@ -1,23 +1,36 @@
-/********************************************
- GFingerPoken Main Window, main()
-********************************************/
+/* main.c - GFingerPoken Main Window, main()
+ * Copyright 1999-2000  Martin Hock
+ * Copyright 2005  Bas Wijnen <shevek@fmf.nl>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ */
 
+#define PNGDIR DATADIR "/png/"
+
+#include <gdk_imlib.h>
 #include <stdlib.h>  /* For rand */
+#include <string.h>  /* For memcpy */
 #include <stdio.h>   /* Only for printf */
 #include <time.h>    /* For time (seed rand) */
+#include <errno.h>   /* For errno */
 
 #include "gfp.h"     /* Constants and "global" function declarations */
 
 #include "initial.h" /* Initialize global vars */
 
-#include "tilepix.h" /* Lots and lots of graphics */
-#include "borderpix.h"
-#include "arrowpix.h"
-#include "marblepix.h"
-#include "markpix.h"
-#include "barpix.h"
-#include "iconpix.h"
-
 
 extern GtkWidget *dialogwin, *netwin;
 
@@ -43,8 +56,8 @@ GdkCursor *makecursor(GdkCursorType cursor_type) {
 
 /* GTK event handlers */
 
-gint anim_loop_timeout(gpointer data) { /* Writes directly to screen.  It's updated frequently anyway. */
-  unsigned int counter=0;               /* Function used to be static */
+gint anim_loop_timeout(G_GNUC_UNUSED gpointer data) { /* Writes directly to screen.  It's updated frequently anyway. */
+  int counter=0;               /* Function used to be static */
   switch (animmode) {
   case 0:
     return TRUE;
@@ -146,7 +159,7 @@ gint anim_loop_timeout(gpointer data) { /* Writes directly to screen.  It's upda
 		      levelpixmap, (updx+1)*pixwidth, (updy+1)*pixheight, (updx+1)*pixwidth, 
 		      (updy+1)*pixheight, pixwidth, pixheight);
     }
-    if ((outx - 1) > (gridx-2) || (outy - 1) > (gridy-2) || evalret < 0) { /* All balls must roll to an end. */
+    if ((outx < 0) || (outy < 0) || (outx + 1 > gridx) || (outy + 1 > gridy) || evalret < 0) { /* All balls must roll to an end. */
       if (histkeeper) freehist(histkeeper);
       if (evalret >= 0) {
 	borderdraw();
@@ -173,7 +186,7 @@ gint anim_loop_timeout(gpointer data) { /* Writes directly to screen.  It's upda
 	do {
 	  /* printf("x: %d y: %d\n",outx, outy); */
 	  grideval(outx, outy, outdir, invisigrid);
-	} while (((outx + 1) < (gridx+1)) && ((outy + 1) < (gridy+1)) && (evalret >= 0));
+	} while ((outx >= 0) && (outy >= 0) && (outx < gridx) && (outy < gridy) && (evalret >= 0));
 	if (histkeeper) freehist(histkeeper);
 	/* if (outx == 0 || outx == gridx+1) outy--; else outx--; */
 	/* printf("Final x: %d y: %d\n",outx,outy); */
@@ -201,11 +214,11 @@ gint anim_loop_timeout(gpointer data) { /* Writes directly to screen.  It's upda
   return TRUE;
 }
 
-void gamebox_destroy_event(GtkWidget *widget, gpointer data) {
+void gamebox_destroy_event(GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   gtk_grab_remove(widget);
 }
 
-void gamebox_button_clicked(GtkWidget *widget, gpointer data) {
+void gamebox_button_clicked(G_GNUC_UNUSED GtkWidget *widget, gpointer data) {
   gtk_widget_destroy(data);
 }
 
@@ -230,7 +243,7 @@ void gamebox(char *title, char *msg) {
   gtk_grab_add(window);
 }
 
-static gint newbarbut_event(GtkWidget *widget, gpointer data) {
+static gint newbarbut_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   if (animmode) return FALSE;
   /*
     setmainpos = 1;
@@ -243,14 +256,14 @@ static gint newbarbut_event(GtkWidget *widget, gpointer data) {
   return FALSE;
 }
 
-static gint stopbarbut_event(GtkWidget *widget, gpointer data) {
+static gint stopbarbut_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   if (animmode) return FALSE;
   netsend('N');
   netkill();
   return FALSE;
 }
 
-static gint checkbarbut_event(GtkWidget *widget, gpointer data) {
+static gint checkbarbut_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   int xcounter=0, ycounter=0;
   pos saveoutx, saveouty;
   vect savedir;
@@ -292,7 +305,7 @@ static gint checkbarbut_event(GtkWidget *widget, gpointer data) {
   tmpgrid = (obj *)malloc(gridx*gridy*sizeof(obj));
   tmpinvisigrid = (obj *)malloc(gridx*gridy*sizeof(obj));
   if (!(tmpgrid && tmpinvisigrid)) {
-    fprintf(stderr, "Insufficient memory for allocating temporary data; needed %d bytes\n",
+    fprintf(stderr, "Insufficient memory for allocating temporary data; needed %zd bytes\n",
 	    2*gridx*gridy*sizeof(obj));
     if (netmode) {
       netsend('N');
@@ -316,7 +329,7 @@ static gint checkbarbut_event(GtkWidget *widget, gpointer data) {
       if (histkeeper) histkeeper = inithist(tmpinvisigrid);  
       do {
 	grideval(outx, outy, outdir, tmpinvisigrid);
-      } while ((outx + 1) < (gridx+1) && (outy + 1) < (gridy+1) && evalret >= 0);
+      } while ((outx >= 0) && (outy >= 0) && (outx < gridx) && (outy < gridy) && evalret >= 0);
       /* printf("Invis out: %d %d %d\n",outx,outy,outdir); */
       if (histkeeper) freehist(histkeeper);
       saveoutx = outx; saveouty = outy; saveret = evalret;
@@ -324,7 +337,7 @@ static gint checkbarbut_event(GtkWidget *widget, gpointer data) {
       if (histkeeper) histkeeper = inithist(tmpgrid);  
       do {
 	grideval(outx, outy, outdir, tmpgrid);
-      } while ((outx + 1) < (gridx+1) && (outy + 1) < (gridy+1) && evalret >= 0);
+      } while ((outx >= 0) && (outy >= 0) && (outx < gridx) && (outy < gridy) && evalret >= 0);
       /* printf("Your out: %d %d %d\n",outx,outy,outdir); */
       if (histkeeper) freehist(histkeeper);
       if ((saveoutx != outx || saveouty != outy) && (saveret != evalret || evalret >= 0)) {
@@ -378,7 +391,7 @@ static gint mainwin_configure_event(GtkWidget *widget, GdkEvent *event) {
 }
 */
 
-static gint netbarbut_event(GtkWidget *widget, gpointer data) {
+static gint netbarbut_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   setstat("Ready");
   /*
     setmainpos = 1;
@@ -389,7 +402,7 @@ static gint netbarbut_event(GtkWidget *widget, gpointer data) {
   return FALSE;
 }
 
-static gint netturnbarbut_event(GtkWidget *widget, gpointer data) {
+static gint netturnbarbut_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   if (paralyzed || pendack || !netmode) return FALSE;
   gtk_widget_hide(mainbarbut[INetTurn]);
   if (category == CatSeparate && opponentdone) {
@@ -404,7 +417,7 @@ static gint netturnbarbut_event(GtkWidget *widget, gpointer data) {
   return FALSE;
 }
 
-static gint flipboardsbarbut_event(GtkWidget *widget, gpointer data) {
+static gint flipboardsbarbut_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   int counter=0;
   obj tmp;
   boardshow = !boardshow;
@@ -428,12 +441,19 @@ static gint flipboardsbarbut_event(GtkWidget *widget, gpointer data) {
   return FALSE;
 }  
 
-static gint aboutbarbut_event(GtkWidget *widget, gpointer data) {
-  gamebox("About GFingerPoken","GFingerPoken 0.25 January 14, 2000\nCode by Martin Hock (oxymoron@cmu.edu)\nGame-specific graphics by Jason Reed (godel@cmu.edu)\nToolbar graphics by Tuomas Kuosmanen (tigert@gimp.org) from gnome-stock\nLicensed under the GNU General Public License version 2 or later\nDistributed with NO WARRANTY, see COPYING for details");
+static gint aboutbarbut_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
+  gamebox(
+    "About GFingerPoken","GFingerPoken 0.26, September 4, 2005\n"
+    "Code by Martin Hock and Bas Wijnen <shevek@fmf.nl>\n"
+    "Maintained by Bas Wijnen <shevek@fmf.nl>\n"
+    "Game-specific graphics by Jason Reed (godel@cmu.edu)\n"
+    "Toolbar graphics by Tuomas Kuosmanen (tigert@gimp.org) from gnome-stock\n"
+    "Licensed under the GNU General Public License version 2 or later\n"
+    "Distributed with NO WARRANTY, see COPYING for details");
   return FALSE;
 }
 
-static gint mainwin_delete_event(GtkWidget *widget, GdkEvent *event, gpointer data) {
+static gint mainwin_delete_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkEvent *event, G_GNUC_UNUSED gpointer data) {
   if (netmode) netkill();
   if (grid) free(grid);
   if (invisigrid) free(invisigrid);
@@ -460,7 +480,7 @@ static gint tooldraw_expose_event(GtkWidget *widget, GdkEventExpose *event) {
   return FALSE;
 }
 
-static gint leveldraw_motion_notify_event(GtkWidget *widget, GdkEventButton *event) {
+static gint leveldraw_motion_notify_event(G_GNUC_UNUSED GtkWidget *widget, GdkEventButton *event) {
   int x, y;
   if (dragorigin != PlNowhere) {
     if (event->state & GDK_BUTTON1_MASK) {
@@ -490,7 +510,7 @@ static gint leveldraw_motion_notify_event(GtkWidget *widget, GdkEventButton *eve
   return FALSE;  
 }
 
-static gint draw_leave_notify_event(GtkWidget *widget, GdkEventCrossing *event) {
+static gint draw_leave_notify_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkEventCrossing *event) {
   /* Because GTK retardedly calls ANOTHER leave when the mouse button is released,
      I must count the number of leaves and entrances.
   */
@@ -506,12 +526,12 @@ static gint draw_leave_notify_event(GtkWidget *widget, GdkEventCrossing *event)
   return FALSE;
 }
 
-static gint simple_enter_notify_event(GtkWidget *widget, GdkEventCrossing *event) {
+static gint simple_enter_notify_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkEventCrossing *event) {
   leavecount = 0;
   return FALSE;
 }
 
-static gint draw_enter_notify_event(GtkWidget *widget, GdkEventCrossing *event) {
+static gint draw_enter_notify_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkEventCrossing *event) {
   leavecount = 0;
   if (dragorigin != PlNowhere) 
     gdk_window_set_cursor(mainwin->window, makecursor(GDK_ICON));
@@ -530,14 +550,14 @@ static gint tooldraw_motion_notify_event(GtkWidget *widget, GdkEventButton *even
   return FALSE;
 }
 */  
-static gint mainwin_button_release_event(GtkWidget *widget, GdkEventButton *event) {
+static gint mainwin_button_release_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkEventButton *event) {
   if (animmode) return FALSE;
   gdk_window_set_cursor(mainwin->window, makecursor(GDK_LEFT_PTR));
   return FALSE;
 }
 
 
-static gint leveldraw_button_press_event(GtkWidget *widget, GdkEventButton *event) {
+static gint leveldraw_button_press_event(G_GNUC_UNUSED GtkWidget *widget, GdkEventButton *event) {
   unsigned int counter=0;
   static guint32 time=0;
   if (animmode) return FALSE;
@@ -602,11 +622,11 @@ static gint leveldraw_button_press_event(GtkWidget *widget, GdkEventButton *even
   return FALSE;
 }
 
-static gint tooldraw_button_press_event(GtkWidget *widget, GdkEventButton *event) {
+static gint tooldraw_button_press_event(G_GNUC_UNUSED GtkWidget *widget, GdkEventButton *event) {
   if (animmode || checked) return FALSE;
   dragmode = 1;
   dragx = 0; dragy = event->y/pixheight; 
-  if (dragy >= bufsize) {
+  if (dragy >= (int)bufsize) {
     dragorigin = PlNowhere;
     gdk_window_set_cursor(mainwin->window, makecursor(GDK_LEFT_PTR));
     return FALSE;
@@ -618,7 +638,7 @@ static gint tooldraw_button_press_event(GtkWidget *widget, GdkEventButton *event
 }
 
 
-static gint leveldraw_button_release_event(GtkWidget *widget, GdkEventButton *event) {
+static gint leveldraw_button_release_event(G_GNUC_UNUSED GtkWidget *widget, GdkEventButton *event) {
   int x = event->x/pixwidth;
   int y = event->y/pixheight;
   if (animmode) return FALSE;
@@ -694,7 +714,7 @@ static gint leveldraw_button_release_event(GtkWidget *widget, GdkEventButton *ev
   return FALSE;
 }
 
-static gint tooldraw_button_release_event(GtkWidget *widget, GdkEventButton *event) {
+static gint tooldraw_button_release_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkEventButton *event) {
   if (animmode) return FALSE;  
   gdk_window_set_cursor(mainwin->window, makecursor(GDK_LEFT_PTR));
   if (checked || (netmode && (pendack || paralyzed))) {dragorigin = PlNowhere; return FALSE;}
@@ -727,70 +747,88 @@ static gint tooldraw_button_release_event(GtkWidget *widget, GdkEventButton *eve
 
 
 /* Initializers */
+GdkPixmap *makemaskpm (const char *file, GdkPixmap **mask)
+{
+  GdkImlibImage *im = gdk_imlib_load_image ((char *)file);
+  GdkPixmap *pm;
+  gint w, h;
+  if (!im)
+    {
+      fprintf (stderr, "Unable to load image %s: %s\n", file, strerror (errno));
+      exit (1);
+    }
+  w = im->rgb_width;
+  h = im->rgb_height;
+  gdk_imlib_render (im, w, h);
+  pm = gdk_imlib_move_image (im);
+  if (mask)
+    *mask = gdk_imlib_move_mask (im);
+  return pm;
+}
 
-#define makepm(a) gdk_pixmap_create_from_xpm_d(mainwin->window, &trashmask, NULL, a)
-#define makemaskpm(a,b) gdk_pixmap_create_from_xpm_d(mainwin->window, &b, NULL, a)
+#define makepm(file) makemaskpm (file, 0)
 
-void initpixmaps() { /* I really should be able to include raw GTK pixmaps, but I don't know of a way to. I have a feeling this is because GTK pixmaps are actually server-side X pixmaps. */
+void initpixmaps() {
+  /*gdk_rgb_init();*/
   /* Non-masked (solid tile) */
-  tilepic[0] = makepm(tile00_xpm);
-  tilepic[1] = makepm(tile01_xpm);
-  tilepic[2] = makepm(tile02_xpm);
-  tilepic[3] = makepm(tile03_xpm);
-  tilepic[4] = makepm(tile04_xpm);
-  tilepic[5] = makepm(tile05_xpm);
-  tilepic[6] = makepm(tile06_xpm);
-  tilepic[7] = makepm(tile07_xpm);
-  tilepic[8] = makepm(tile08_xpm);
-  tilepic[9] = makepm(tile09_xpm);
-  tilepic[10] = makepm(tile10_xpm);
-  tilepic[11] = makepm(tile11_xpm);
-  tilepic[12] = makepm(tile12_xpm);
-  tilepic[13] = makepm(tile13_xpm);
-  tilepic[14] = makepm(tile14_xpm);
-  tilepic[15] = makepm(tile15_xpm);
-  tilepic[16] = makepm(tile16_xpm);
-  tilepic[17] = makepm(tile17_xpm);
-  tilepic[18] = makepm(tile18_xpm);
-  tilepic[19] = makepm(tile19_xpm);
-  tilepic[20] = makepm(tile20_xpm);
-  tilepic[21] = makepm(tile21_xpm);
-  tilepic[22] = makepm(tile22_xpm);
-  tilepic[23] = makepm(tile23_xpm);
-  tilepic[24] = makepm(tile24_xpm);
-  tilepic[25] = makepm(tile25_xpm);
-  tilepic[26] = makepm(tile26_xpm);
-  tilepic[27] = makepm(tile27_xpm);
-  tilepic[28] = makepm(tile28_xpm);
-  tilepic[29] = makepm(tile29_xpm);
-  tilepic[30] = makepm(tile30_xpm);
-  tilepic[31] = makepm(tile31_xpm);
-  tilepic[32] = makepm(tile32_xpm);
-  borderpix = makepm(picBorder);
+  tilepic[0] = makepm(PNGDIR "00_bg.png");
+  tilepic[1] = makepm(PNGDIR "01_normal.png");
+  tilepic[2] = makepm(PNGDIR "02_normal.png");
+  tilepic[3] = makepm(PNGDIR "03_flip2.png");
+  tilepic[4] = makepm(PNGDIR "04_flip2.png");
+  tilepic[5] = makepm(PNGDIR "05_flip4.png");
+  tilepic[6] = makepm(PNGDIR "06_flip4.png");
+  tilepic[7] = makepm(PNGDIR "07_flip4.png");
+  tilepic[8] = makepm(PNGDIR "08_flip4.png");
+  tilepic[9] = makepm(PNGDIR "09_block.png");
+  tilepic[10] = makepm(PNGDIR "10_sink.png");
+  tilepic[11] = makepm(PNGDIR "11_axial.png");
+  tilepic[12] = makepm(PNGDIR "12_axial.png");
+  tilepic[13] = makepm(PNGDIR "13_axial2.png");
+  tilepic[14] = makepm(PNGDIR "14_axial2.png");
+  tilepic[15] = makepm(PNGDIR "15_rotator.png");
+  tilepic[16] = makepm(PNGDIR "16_rotator.png");
+  tilepic[17] = makepm(PNGDIR "17_rotator2.png");
+  tilepic[18] = makepm(PNGDIR "18_rotator2.png");
+  tilepic[19] = makepm(PNGDIR "19_half.png");
+  tilepic[20] = makepm(PNGDIR "20_half.png");
+  tilepic[21] = makepm(PNGDIR "21_half.png");
+  tilepic[22] = makepm(PNGDIR "22_half.png");
+  tilepic[23] = makepm(PNGDIR "23_half4.png");
+  tilepic[24] = makepm(PNGDIR "24_half4.png");
+  tilepic[25] = makepm(PNGDIR "25_half4.png");
+  tilepic[26] = makepm(PNGDIR "26_half4.png");
+  tilepic[27] = makepm(PNGDIR "27_half4.png");
+  tilepic[28] = makepm(PNGDIR "28_half4.png");
+  tilepic[29] = makepm(PNGDIR "29_half4.png");
+  tilepic[30] = makepm(PNGDIR "30_half4.png");
+  tilepic[31] = makepm(PNGDIR "31_move.png");
+  tilepic[32] = makepm(PNGDIR "32_move.png");
+  borderpix = makepm(PNGDIR "picBorder.png");
   /* Masked (sprite) */
-  arrowpix[DUp] = makemaskpm(picDUp, arrowmask[DUp]);
-  arrowpix[DRight] = makemaskpm(picDRight, arrowmask[DRight]);
-  arrowpix[DDown] = makemaskpm(picDDown, arrowmask[DDown]);
-  arrowpix[DLeft] = makemaskpm(picDLeft, arrowmask[DLeft]);
-  warrowpix[DUp] = makepm(picDUpW);
-  warrowpix[DRight] = makepm(picDRightW);
-  warrowpix[DDown] = makepm(picDDownW);
-  warrowpix[DLeft] = makepm(picDLeftW);
-  markpix[0] = makemaskpm(picMkCircle, markmask[0]);
-  markpix[1] = makemaskpm(picMkTriangle, markmask[1]);
-  markpix[2] = makemaskpm(picMkSquare, markmask[2]);
-  marblepix = makemaskpm(picMarble, marblemask);
-  iconpix = makemaskpm(picIcon, iconmask);
-  barpix[INew] = makemaskpm(picINew, barmask[INew]);
-  barpix[IStop] = makemaskpm(picIStop, barmask[IStop]);
-  barpix[ICheck] = makemaskpm(picICheck, barmask[ICheck]);
-  barpix[INet] = makemaskpm(picINet, barmask[INet]);
-  barpix[INetTurn] = makemaskpm(picINetTurn, barmask[INetTurn]);
-  barpix[IFlipBoards] = makemaskpm(picIFlipBoards, barmask[IFlipBoards]);
-  barpix[IFlipBack] = makemaskpm(picIFlipBack, barmask[IFlipBack]);
-  barpix[IAbout] = makemaskpm(picIAbout, barmask[IAbout]);
-  barpix[IOpen] = makemaskpm(picIOpen, barmask[IOpen]);
-  barpix[ISave] = makemaskpm(picISave, barmask[ISave]);
+  arrowpix[DUp] = makemaskpm(PNGDIR "picDUp.png", &arrowmask[DUp]);
+  arrowpix[DRight] = makemaskpm(PNGDIR "picDRight.png", &arrowmask[DRight]);
+  arrowpix[DDown] = makemaskpm(PNGDIR "picDDown.png", &arrowmask[DDown]);
+  arrowpix[DLeft] = makemaskpm(PNGDIR "picDLeft.png", &arrowmask[DLeft]);
+  warrowpix[DUp] = makepm(PNGDIR "picDUpW.png");
+  warrowpix[DRight] = makepm(PNGDIR "picDRightW.png");
+  warrowpix[DDown] = makepm(PNGDIR "picDDownW.png");
+  warrowpix[DLeft] = makepm(PNGDIR "picDLeftW.png");
+  markpix[0] = makemaskpm(PNGDIR "picMkCircle.png", &markmask[0]);
+  markpix[1] = makemaskpm(PNGDIR "picMkTriangle.png", &markmask[1]);
+  markpix[2] = makemaskpm(PNGDIR "picMkSquare.png", &markmask[2]);
+  marblepix = makemaskpm(PNGDIR "marbles.png", &marblemask);
+  iconpix = makemaskpm(PNGDIR "gfpoken.png", &iconmask);
+  barpix[INew] = makemaskpm(PNGDIR "picINew.png", &barmask[INew]);
+  barpix[IStop] = makemaskpm(PNGDIR "picIStop.png", &barmask[IStop]);
+  barpix[ICheck] = makemaskpm(PNGDIR "picICheck.png", &barmask[ICheck]);
+  barpix[INet] = makemaskpm(PNGDIR "picINet.png", &barmask[INet]);
+  barpix[INetTurn] = makemaskpm(PNGDIR "picINetTurn.png", &barmask[INetTurn]);
+  barpix[IFlipBoards] = makemaskpm(PNGDIR "picIFlipBoards.png", &barmask[IFlipBoards]);
+  barpix[IFlipBack] = makemaskpm(PNGDIR "picIFlipBack.png", &barmask[IFlipBack]);
+  barpix[IAbout] = makemaskpm(PNGDIR "picIAbout.png", &barmask[IAbout]);
+  barpix[IOpen] = makemaskpm(PNGDIR "picIOpen.png", &barmask[IOpen]);
+  barpix[ISave] = makemaskpm(PNGDIR "picISave.png", &barmask[ISave]);
 }
 
 
@@ -909,13 +947,12 @@ void shownetturn() {
 int main(int argc, char *argv[]) {
   srandom(time(NULL));
   gtk_init(&argc, &argv);
+  gdk_imlib_init ();
+  gtk_widget_push_visual(gdk_imlib_get_visual());
+  gtk_widget_push_colormap(gdk_imlib_get_colormap());
   initmainwin();
   initnetwin();
   initdialog();
   gtk_main();
   return 0;
 }
-
-
-
-
