@@ -1,6 +1,22 @@
-/********************************************
- GFingerPoken Multiplayer Window, Networking
-********************************************/
+/* multi.c - GFingerPoken Multiplayer Window, Networking
+ * Copyright 1999-2000  Martin Hock
+ * Copyright 2005  Bas Wijnen <shevek@fmf.nl>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ */
 
 #include <stdarg.h> /* For variable arguments in netsend */
 #include <sys/types.h> /* For types needed in net stuff */
@@ -71,7 +87,7 @@ void setstat(char *msg) {
   /* printf("%s\n",msg); */
 }
 
-static gint netok_clicked(GtkWidget *widget, gpointer data) {
+static gint netok_clicked(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   int counter=0;
   int connection=0;
   if (netmode) return FALSE;
@@ -117,14 +133,14 @@ static gint netok_clicked(GtkWidget *widget, gpointer data) {
   return FALSE;
 }
 
-static gint netcancel_clicked(GtkWidget *widget, gpointer data) {
+static gint netcancel_clicked(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data) {
   if (netmode) netkill();
   gtk_widget_hide(netwin);
   gtk_widget_show(mainwin);
   return FALSE;
 }
 
-static gint netwin_delete_event(GtkWidget *widget, GdkEvent *event, gpointer data) {
+static gint netwin_delete_event(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkEvent *event, G_GNUC_UNUSED gpointer data) {
   if (netmode) netkill();
   gtk_widget_hide(netwin);
   gtk_widget_show(mainwin);
@@ -309,7 +325,7 @@ void netsend(char type, ...) { /* type, then each arg in turn, i.e.: 'M', x1, y1
   
 }
 
-gint netmonitor(gpointer data, gint source, GdkInputCondition condition) {
+gint netmonitor(G_GNUC_UNUSED gpointer data, G_GNUC_UNUSED gint source, G_GNUC_UNUSED GdkInputCondition condition) {
   char newin[Linelen] = "";
   char *inptr = netin+2;
   int tmp, x, y;
@@ -444,7 +460,7 @@ gint netmonitor(gpointer data, gint source, GdkInputCondition condition) {
 }
 
 
-gint clientmonitor(gpointer data, gint source, GdkInputCondition condition) {
+gint clientmonitor(G_GNUC_UNUSED gpointer data, G_GNUC_UNUSED gint source, G_GNUC_UNUSED GdkInputCondition condition) {
   char newin[Linelen] = "";
   char *st = newin+2;
   int counter=0;
@@ -501,7 +517,7 @@ gint clientmonitor(gpointer data, gint source, GdkInputCondition condition) {
     if (invisigrid) free(invisigrid); invisigrid = (obj *)malloc(gridx*gridy*sizeof(obj)); /* will be completely filled */
     if (markgrid) free(markgrid); markgrid = (obj *)calloc(gridx*gridy, sizeof(obj));
     if (!(grid && invisigrid && markgrid)) {
-      fprintf(stderr, "Insufficient memory for allocating level; needed %d bytes\n",
+      fprintf(stderr, "Insufficient memory for allocating level; needed %zd bytes\n",
 	      3*gridx*gridy*sizeof(obj));
       exit(1);
     }
@@ -521,7 +537,7 @@ gint clientmonitor(gpointer data, gint source, GdkInputCondition condition) {
     break;
   case 'B': /* Board data */
     /* printf("Client: Decoding board data...\n"); */
-    for(; *st != '\n'; blockspot++) { /* Danger is my middle name */
+    for(; *st && *st != '\n'; blockspot++) {
       if ((invisigrid[blockspot] = strtol(st, &st, 10))) {
 	dragbuf[objtodr(invisigrid[blockspot])]++;
 	bufsize++;
@@ -580,7 +596,7 @@ gint clientmonitor(gpointer data, gint source, GdkInputCondition condition) {
   return TRUE;
 }
 
-gint servermonitor(gpointer data, gint source, GdkInputCondition condition) {
+gint servermonitor(G_GNUC_UNUSED gpointer data, G_GNUC_UNUSED gint source, G_GNUC_UNUSED GdkInputCondition condition) {
   char newin[Linelen] = "";
   int counter = 0;
   switch (read(remotesock, newin, SSIZE_MAX > Linelen-1 ? Linelen-1 : SSIZE_MAX)) {
@@ -680,8 +696,8 @@ gint servermonitor(gpointer data, gint source, GdkInputCondition condition) {
   return TRUE;
 }
 
-gint accept_loop_timeout(gpointer data) {
-  int clientlen;
+gint accept_loop_timeout(G_GNUC_UNUSED gpointer data) {
+  socklen_t clientlen = sizeof (struct sockaddr_in);
   if ((remotesock = accept(localsock, (struct sockaddr *)&remoteaddr, &clientlen)) == -1) {
     switch (errno) {
     case EWOULDBLOCK:
